==> selenium-server-2.28.0-sources.jar: org/openqa/selenium/remote/server/handler/GetSessionLogsHandler.java <==
/*
Copyright 2012 Software Freedom Conservatory.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.openqa.selenium.remote.server.handler;

import org.openqa.selenium.logging.SessionLogs;
import org.openqa.selenium.remote.Response;
import org.openqa.selenium.remote.SessionId;
import org.openqa.selenium.remote.server.rest.RestishHandler;
import org.openqa.selenium.remote.server.rest.ResultType;
import org.openqa.selenium.server.log.LoggingManager;

import com.google.common.collect.ImmutableMap;

public class GetSessionLogsHandler implements RestishHandler {

  private final Response response = new Response();

  public Response getResponse() {
    return response;
  }

  public ResultType handle() throws Exception {
    ImmutableMap.Builder<String, SessionLogs> builder =
        ImmutableMap.<String, SessionLogs>builder();
    for (SessionId sessionId : LoggingManager.perSessionLogHandler().getLoggedSessions()) {
      builder.put(sessionId.toString(),
          LoggingManager.perSessionLogHandler().getAllLogsForSession(sessionId));
    }
    response.setValue(builder.build());
    return ResultType.SUCCESS;
  }

  @Override
  public String toString() {
    return String.format("[fetching session logs]");
  }
}

==> selenium-server-2.40.0-sources.jar: org/openqa/selenium/remote/server/handler/GetSessionLogsHandler.java <==
/*
Copyright 2012 Software Freedom Conservatory.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.openqa.selenium.remote.server.handler;

import com.google.common.collect.ImmutableMap;

import org.openqa.selenium.logging.SessionLogs;
import org.openqa.selenium.remote.Response;
import org.openqa.selenium.remote.SessionId;
import org.openqa.selenium.remote.server.log.LoggingManager;
import org.openqa.selenium.remote.server.rest.RestishHandler;
import org.openqa.selenium.remote.server.rest.ResultType;

public class GetSessionLogsHandler implements RestishHandler {

  private final Response response = new Response();

  public Response getResponse() {
    return response;
  }

  public ResultType handle() throws Exception {
    ImmutableMap.Builder<String, SessionLogs> builder =
        ImmutableMap.<String, SessionLogs>builder();
    for (SessionId sessionId : LoggingManager.perSessionLogHandler().getLoggedSessions()) {
      builder.put(sessionId.toString(),
          LoggingManager.perSessionLogHandler().getAllLogsForSession(sessionId));
    }
    response.setValue(builder.build());
    return ResultType.SUCCESS;
  }

  @Override
  public String toString() {
    return String.format("[fetching session logs]");
  }
}
